@@ -5,4 +5,4 @@ __email__ = 'OCRfixr@mcmahon.work'
 __version__ = '0.1.0'
 
 from .spellcheck import spellcheck
-#from .spellcheck import unsplit
+from .unsplit import unsplit
