@@ -19,21 +19,21 @@ word_set = (ocrfixr / "data" / "SCOWL_70.txt").read_text(encoding='utf-8').split
 word_set = set(word_set)
 
 # List of words NOT in SCOWL 70 that we should ignore anyways
-ignore_misreads = (ocrfixr / "data" / "ignore_these_misspells.txt").read_text(encoding='utf-8').split()
+ignore_misreads = (ocrfixr / "data" / "Ignore_These_Misspells.txt").read_text(encoding='utf-8').split()
 ignore_set_from_pkg = set(ignore_misreads)
 
 # dict of common scannos to check for (bypasses the context check, since these are clear mappings)
-common_scannos = (ocrfixr / "data" / "scannos_common.txt").read_text(encoding='utf-8')
+common_scannos = (ocrfixr / "data" / "Scannos_Common.txt").read_text(encoding='utf-8')
 common_scannos = ast.literal_eval(common_scannos)
 common = set(common_scannos)
 
 # dict of specifically tricky scannos to check for - misspellings that create real words (arid - and)
-stealth_scannos = (ocrfixr / "data" / "scannos_stealth.txt").read_text(encoding='utf-8')
+stealth_scannos = (ocrfixr / "data" / "Scannos_Stealth.txt").read_text(encoding='utf-8')
 stealth_scannos = ast.literal_eval(stealth_scannos)
 stealth = set(stealth_scannos)
 
 # dict of OCRfixr suggestions that are known to be bad. This list prevents them from ever being suggested.
-ignore_suggestions = (ocrfixr / "data" / "ignore_these_suggestions.txt").read_text(encoding='utf-8')
+ignore_suggestions = (ocrfixr / "data" / "Ignore_These_Suggestions.txt").read_text(encoding='utf-8')
 ignore_suggestions = ast.literal_eval(ignore_suggestions)
 #ignore_suggestions = set(ignore_suggestions)
 
@@ -74,6 +74,7 @@ class spellcheck:
         return(tokens)
 
     # Find all mispelled words in a passage.
+    # Note: OCRfixr ignores all words with leading uppercasing (including ALL CAPS), as these are assumed to be proper nouns, which fall outside of the scope of what a dictionary-based approach can accomplish.
     def _LIST_MISREADS(self):
         tokens = re.split("[ \n]", self.text)
         tokens = [l.strip() for l in tokens] 
@@ -263,6 +264,7 @@ class spellcheck:
         
     # Creates a dict of valid replacements for misspellings. If bert and symspell do not have a match for a given misspelling, it makes no changes to the word.
     # When common_scannos is activated, that limited list of words bypass the spellcheck/context check
+    # Note: find-replace is not instance-specific, it is paragraph specific..."yov" will be replaced with "you" in all instances found in that section of text. It would be rare, but this may cause issues when a repeated scanno is valid & not valid within the same paragraph
     def _FIND_REPLACEMENTS(self, misreads):
         SC = [] 
         bert = []
@@ -447,7 +449,7 @@ class spellcheck:
                     full_results = []
                 else:
                     full_results = []
-                    # TODO - Need to make this iterate through all items in the fixes dict (currently only does the first)
+                    # iterate through all items in the fixes dict & output each suggestion in format required by GuiGuts
                     for key, value in fixes.items():    
                         txt = re.sub('^[0-9]+: ', '', self.text)
                         loc = txt.find(key) - 1
@@ -500,16 +502,14 @@ class spellcheck:
 
 # TODO - (ADD_DICTS) Need to add selectable foreign language dictionaries 
 # TODO - (IGNORE_SPLIT_WORDS) need to ignore the first word of a new page, since these can be split words across pages (this may also just be tied up in the unsplit functionality, where this word should have a leading * to denote a split word)
-# TODO - (ADD_STEALTHOS) Need to add additional common stealth scannos to OCRfixr
-# TODO - (FULL_PARAGRAPHS) Need to allow BERT context to draw from all lines in a full paragraph (currently resets at each newline -- this corresponds to 1 line of text in a Gutenberg text, and likely leads to degraded spellcheck performance due to loss of context)
+# TODO - (ADD_STEALTHOS) Need to add additional common stealth scannos to OCRfixr. Be mindful, as these can increase compute time hugely (eg. he/be). Shoot for words that are uncommon (arid --> and)
+# TODO - (FULL_PARAGRAPHS) Allow BERT context to draw from all lines in a full paragraph (currently resets at each newline -- this corresponds to 1 line of text in a Gutenberg text, and likely leads to degraded spellcheck performance due to loss of context). However, longer context window = slower performance
+#          > most useful case for this is when the MASKED word is the first or last word in the line
+#          > exploring the option of accepting synonyms for context words as valid spellcheck replacements (ex. "the dark, [MASK] swamp". wet --> damp)
 # TODO - (GutenBERT) fine-tune BERT model on Gutenberg texts, to improve relatedness of context suggestions
 # TODO - (WARM_UP) can we somehow negate the warm-up time for the transformers unmasker?
     # pipelines = 7 secs
     # symspellpy dictionary load = 3 seconds
 
 
-# Note: find-replace is not instance-specific, it is paragraph specific..."yov" will be replaced with "you" in all instances found in that section of text. It would be rare, but this may cause issues when a repeated scanno is valid & not valid within the same paragraph
-# Note: OCRfixr ignores all words with leading uppercasing, as these are assumed to be proper nouns, which fall outside of the scope of what this approach can accomplish.
-
-
        
